@@ -1,3 +1,6 @@
+# SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
+# SPDX-License-Identifier: MIT
+
 """This example is for Raspberry Pi (Linux) only!
    It will not work on microcontrollers running CircuitPython!"""
 
@@ -64,7 +67,7 @@ def map_value(x_value, in_min, in_max, out_min, out_max):
 
 
 def print_there(console_x, console_y, text, color):
-    """ Outputs a colored text to console at coordinates """
+    """Outputs a colored text to console at coordinates"""
     sys.stdout.write("\x1b7\x1b[48;5;%dm" % (color))
     sys.stdout.write("\x1b7\x1b[%d;%df%s\x1b8" % (console_x, console_y, text))
 
@@ -95,8 +98,7 @@ while True:
             color_index = 0
             if COLOR_RANGE != 0:
                 color_index = int(round((pixel - MINPIXEL) / COLOR_RANGE))
-            if color_index < 0:
-                color_index = 0
+            color_index = max(color_index, 0)
             if color_index > len(CONSOLE_COLORS) - 1:
                 color_index = len(CONSOLE_COLORS) - 1
             print_there(x_console, Y_CONSOLE * 2 - 2, "  ", CONSOLE_COLORS[color_index])
